@@ -1389,7 +1389,9 @@ UT_Confidence_t IE_Imp_MSWorks_Sniffer::recognizeContents (GsfInput * input)
 	AbiWordperfectInputStream gsfInput(input);
 
 	libwps::WPSKind kind;
-	libwps::WPSConfidence confidence = libwps::WPSDocument::isFileFormatSupported(&gsfInput, kind);
+        libwps::WPSCreator creator;
+        bool needsEncoding = false;
+	libwps::WPSConfidence confidence = libwps::WPSDocument::isFileFormatSupported(&gsfInput, kind, creator, needsEncoding);
 	
 	if (kind != libwps::WPS_TEXT)
 		confidence = libwps::WPS_CONFIDENCE_NONE;
